==> jc-1.4.0.tar.gz: soot/TrapManager.h <==
// public class soot.TrapManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 98b0bd7e42600d7b soot_TrapManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_TrapManager_H_
#define _JC_soot_TrapManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_TrapManager$sub_refs	_jc_soot_TrapManager$sub_refs;
typedef struct _jc_soot_TrapManager$sub_nonrefs	_jc_soot_TrapManager$sub_nonrefs;
typedef struct _jc_soot_TrapManager$refs	_jc_soot_TrapManager$refs;
typedef struct _jc_soot_TrapManager$nonrefs	_jc_soot_TrapManager$nonrefs;
typedef struct _jc_soot_TrapManager$object	_jc_soot_TrapManager$object;

typedef const struct _jc_soot_TrapManager$vmethods	_jc_soot_TrapManager$vmethods;
typedef const struct _jc_soot_TrapManager$vtable	_jc_soot_TrapManager$vtable;
typedef const struct _jc_soot_TrapManager$vtype	_jc_soot_TrapManager$vtype;

// Constructors
extern void _jc_soot_TrapManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_TrapManager$object *);

// Static methods
extern struct _jc_object *_jc_soot_TrapManager$method$getExceptionTypesOf$e478e22421e25f27(_jc_env *, struct _jc_object *, struct _jc_soot_Body$object *);
extern struct _jc_object *_jc_soot_TrapManager$method$getTrappedUnitsOf$2dab19a16dd04fa7(_jc_env *, struct _jc_soot_Body$object *);
extern struct _jc_object *_jc_soot_TrapManager$method$getTrapsAt$082b35ab50c2c0af(_jc_env *, struct _jc_object *, struct _jc_soot_Body$object *);
extern jboolean _jc_soot_TrapManager$method$isExceptionCaughtAt$0bd3ddcf2b384f83(_jc_env *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_soot_Body$object *);
extern void _jc_soot_TrapManager$method$splitTrapsAgainst$7e929330b600370a(_jc_env *, struct _jc_soot_Body$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_TrapManager$vmethods {
};

// Vtable
struct _jc_soot_TrapManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TrapManager$vmethods	soot_TrapManager;
};

// Vtype
struct _jc_soot_TrapManager$vtype {
	_jc_type			type;
	_jc_soot_TrapManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_TrapManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_TrapManager$refs {
    _jc_soot_TrapManager$sub_refs	soot_TrapManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_TrapManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_TrapManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TrapManager$sub_nonrefs	soot_TrapManager;
};

// Object instance structure
struct _jc_soot_TrapManager$object {
	_jc_soot_TrapManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_TrapManager$vtype	*vtype;
	_jc_soot_TrapManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_TrapManager$vtype _jc_soot_TrapManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_TrapManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_TrapManager$class_object;

#endif	/* _JC_soot_TrapManager_H_ */

==> jc-1.4.6.tar.gz: soot/TrapManager.h <==
// public class soot.TrapManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 98b0bd7e42600d7b soot_TrapManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_TrapManager_H_
#define _JC_soot_TrapManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_TrapManager$sub_refs	_jc_soot_TrapManager$sub_refs;
typedef struct _jc_soot_TrapManager$sub_nonrefs	_jc_soot_TrapManager$sub_nonrefs;
typedef struct _jc_soot_TrapManager$refs	_jc_soot_TrapManager$refs;
typedef struct _jc_soot_TrapManager$nonrefs	_jc_soot_TrapManager$nonrefs;
typedef struct _jc_soot_TrapManager$object	_jc_soot_TrapManager$object;

typedef const struct _jc_soot_TrapManager$vmethods	_jc_soot_TrapManager$vmethods;
typedef const struct _jc_soot_TrapManager$vtable	_jc_soot_TrapManager$vtable;
typedef const struct _jc_soot_TrapManager$vtype	_jc_soot_TrapManager$vtype;

// Constructors
extern void _jc_soot_TrapManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_TrapManager$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_soot_TrapManager$method$getExceptionTypesOf$e478e22421e25f27(_jc_env *, struct _jc_object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_TrapManager$method$getTrappedUnitsOf$2dab19a16dd04fa7(_jc_env *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_TrapManager$method$getTrapsAt$082b35ab50c2c0af(_jc_env *, struct _jc_object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_TrapManager$method$isExceptionCaughtAt$0bd3ddcf2b384f83(_jc_env *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern void _jc_soot_TrapManager$method$splitTrapsAgainst$7e929330b600370a(_jc_env *, struct _jc_soot_Body$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_TrapManager$vmethods {
};

// Vtable
struct _jc_soot_TrapManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TrapManager$vmethods	soot_TrapManager;
};

// Vtype
struct _jc_soot_TrapManager$vtype {
	_jc_type			type;
	_jc_soot_TrapManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_TrapManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_TrapManager$refs {
    _jc_soot_TrapManager$sub_refs	soot_TrapManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_TrapManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_TrapManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TrapManager$sub_nonrefs	soot_TrapManager;
};

// Object instance structure
struct _jc_soot_TrapManager$object {
	_jc_soot_TrapManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_TrapManager$vtype	*vtype;
	_jc_soot_TrapManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_TrapManager$vtype _jc_soot_TrapManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_TrapManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_TrapManager$class_object;

#endif	/* _JC_soot_TrapManager_H_ */
